XML
===

This sub-package defines classes for working with XML documents.  The
version of the standard implemented is the Extensible Markup Language
(Fifth Edition), for more info see: http://www.w3.org/TR/xml/

.. toctree::
    :maxdepth: 2

    xml/introduction
    xml/structures
    xml/namespace
    xml/parser
    xml/xsdatatypes


